import { Component, OnInit, ViewChild } from "@angular/core";
import { NgbModal } from "@ng-bootstrap/ng-bootstrap";
import { NgBlockUI, BlockUI } from "ng-block-ui";
import {
  PerfectScrollbarDirective,
  PerfectScrollbarComponent,
  PerfectScrollbarConfigInterface,
} from "ngx-perfect-scrollbar";
import { TableApiService } from "src/app/_services/table-api.service";
import { ModalAddEditComponent } from "./modal-add-edit/modal-add-edit.component";
import { ActivatedRoute, Router } from "@angular/router";

@Component({
  selector: "app-device",
  templateUrl: "./device.component.html",
  styleUrls: ["./device.component.css"],
})
export class DeviceComponent implements OnInit {
  data: any;
  filteredRows: any[];
  searchTerm: string = '';

  @BlockUI("addRows") blockUIAddRows: NgBlockUI;
  @BlockUI("rowSelection") blockUIRowSelection: NgBlockUI;

  public config: PerfectScrollbarConfigInterface = { wheelPropagation: true };
  @ViewChild(PerfectScrollbarComponent)
  componentRef?: PerfectScrollbarComponent;
  @ViewChild(PerfectScrollbarDirective, { static: true })
  directiveRef?: PerfectScrollbarDirective;

  options = {
    close: true,
    expand: true,
    minimize: true,
    reload: true,
  };
  temp = [];
  selected = [];
  id: number;
  loadingIndicator: true;
  rows: any;
  editing = {};
  row: any;
  public breadcrumb: any;

  constructor(
    private tableApiservice: TableApiService,
    private modalService: NgbModal,
    private router: Router
  ) {}

  ngOnInit() {
    this.fetchData();
  }

  fetchData() {
    this.tableApiservice.getTableApiData().subscribe((response) => {
      this.data = response;
      this.filteredRows = this.data.rows;
    });
  }

  filterRows() {
    if (!this.searchTerm) {
      this.filteredRows = [...this.data.rows];
    } else {
      this.filteredRows = this.data.rows.filter((row) =>
        this.rowContainsSearchTerm(row)
      );
    }
  }

  rowContainsSearchTerm(row: any): boolean {
    const searchTermLC = this.searchTerm.toLowerCase();
    return Object.values(row).some(
      (value) =>
        value !== null &&
        value.toString().toLowerCase().includes(searchTermLC)
    );
  }

  // private newAttribute = {
  //   id: 15,
  //   name: "Mark",
  //   position: "Otto",
  //   office: "@mdo",
  //   age: "31",
  //   salary: "12000",
  //   startdate: "16/05/2017",
  // };

  // addFieldValue() {
  //   this.rows.push(this.newAttribute);
  //   this.rows = [...this.rows];
  // }

  addFieldValue() {
    const modalRef = this.modalService.open(ModalAddEditComponent, { size: 'lg' });
    modalRef.componentInstance.newAttribute = { id: null, name: '', position: '', office: '', age: '', salary: '', startdate: '' };
  
    modalRef.result.then((result) => {
      if (result) {
        this.rows.push(result);
        this.rows = [...this.rows];
      }
    }, (reason) => {
      console.log(`Dismissed: ${reason}`);
    });
  }

  viewRow(row) {
    console.log("View row:", row);
    this.router.navigate(['/device/view', row.id]);
  }
  
  editRow(row) {
    console.log("Edit row:", row);
    this.router.navigate(['/device/edit', row.id]);
  }
  
  deleteRow(row) {
    console.log("Delete row:", row);
  }
  
  
}
